/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Represents the options for applying a command to the "word" at the cursor position.
 * Use the `before` and `after` regular expressions to define what counts as a word boundary ([see example]({% slug toolbartools_editor %}#toc-customizing-word-delimiters)).
 *
 * @example
 * ```typescript
 * const options: ApplyToWordOptions = {
 *   before: /\s/,
 *   after: /\s/
 * };
 * ```
 */
export interface ApplyToWordOptions {
    /**
     * Defines the regular expression for the start boundary of the word before the cursor.
     */
    before: RegExp;
    /**
     * Defines the regular expression for the end boundary of the word after the cursor.
     */
    after: RegExp;
}
