/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EditorState, Transaction, EditorView } from '@progress/kendo-editor-common';
/**
 * @hidden
 */
export type DispatchFn = (tr: Transaction) => void;
/**
 * @hidden
 */
export type Command = (state: EditorState, dispatch: DispatchFn, view?: EditorView) => boolean | void;
/**
 * @hidden
 */
export type EditorInternalCommand = 'print';
/**
 * Lists the command names accepted by the `exec` method.
 */
export type EditorCommand = 'bold' | 'italic' | 'underline' | 'strikethrough' | 'createLink' | 'unlink' | 'insertFile' | 'insertImage' | 'insertOrderedList' | 'insertUnorderedList' | 'insertText' | 'indent' | 'outdent' | 'alignLeft' | 'alignCenter' | 'alignRight' | 'alignJustify' | 'format' | 'fontFamily' | 'fontSize' | 'cleanFormat' | 'setHTML' | 'undo' | 'redo' | 'subscript' | 'superscript' | 'cleanFormatting' | 'foreColor' | 'backColor' | 'insertTable' | 'addColumnBefore' | 'addColumnAfter' | 'addRowBefore' | 'addRowAfter' | 'deleteRow' | 'deleteColumn' | 'mergeCells' | 'splitCell' | 'deleteTable' | 'selectAll' | 'blockquote';
/**
 * Lists the dialog commands accepted by the `openDialog` method.
 *
 * Supported dialog commands:
 * - `createLink`
 * - `viewSource`
 * - `insertFile`
 * - `insertImage`
 * - `tableWizard`
 *
 * @example
 * ```typescript
 * // Open a `createLink` dialog.
 * editor.openDialog('createLink');
 *
 * // Open a `viewSource` dialog.
 * editor.openDialog('viewSource');
 * ```
 */
export type DialogCommand = 'createLink' | 'insertFile' | 'insertImage' | 'viewSource';
