/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Represents the settings for applying custom CSS styles to the Editor in iframe mode ([see example](slug:styling_editor#toc-encapsulated-mode)).
 *
 * @example
 * ```typescript
 * const cssSettings: EditorCssSettings = {
 *   content: '.k-editor { color: red; }',
 *   path: '/styles/editor.css',
 *   keepBuiltInCss: false
 * };
 * ```
 */
export interface EditorCssSettings {
    /**
     * Sets the CSS rules to apply.
     */
    content?: string;
    /**
     * Sets the path to an external style sheet.
     */
    path?: string;
    /**
     * Determines if custom styles override or extend built-in styles.
     */
    keepBuiltInCss?: boolean;
}
