/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Represents a single item in the font size DropDownList.
 *
 * @example
 * ```typescript
 * const fontSizeItem: FontSizeItem = {
 *   size: 14,
 *   text: '14px'
 * };
 * ```
 */
export interface FontSizeItem {
    /**
     * Sets the value of the [`font-size`](https://developer.mozilla.org/en-US/docs/Web/CSS/font-size) CSS property.
     */
    size: number | string;
    /**
     * Sets the display text for the font size in the DropDownList.
     */
    text: string;
}
