/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Represents the size restrictions for the resizable Editor ([see example](slug:resizing_editor#toc-resizing-the-editor)).
 *
 * @example
 * ```typescript
 * const options: EditorResizableOptions = {
 *   minWidth: 200,
 *   minHeight: 100,
 *   maxWidth: 800,
 *   maxHeight: 600
 * };
 * ```
 */
export interface EditorResizableOptions {
    /**
     * Sets the minimum width of the resizable Editor in pixels.
     */
    minWidth?: number;
    /**
     * Sets the minimum height of the resizable Editor in pixels.
     */
    minHeight?: number;
    /**
     * Sets the maximum width of the resizable Editor in pixels.
     */
    maxWidth?: number;
    /**
     * Sets the maximum height of the resizable Editor in pixels.
     */
    maxHeight?: number;
}
