/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from "./preventable-event";
/**
 * Fires when the Editor [`paste`]({% slug api_editor_editorcomponent %}#toc-paste) event occurs.
 */
export class EditorPasteEvent extends PreventableEvent {
    /**
     * Contains the HTML content cleaned according to the [`PasteCleanupSettings`]({% slug paste_cleanup %}).
     */
    cleanedHtml;
    /**
     * Contains the raw pasted content.
     */
    originalHtml;
    /**
     * Contains the original DOM event.
     */
    originalEvent;
    /**
     * Constructs the event arguments for the `paste` event.
     * @hidden
     */
    constructor(cleanedHtml, originalHtml, originalEvent) {
        super();
        this.cleanedHtml = cleanedHtml;
        this.originalHtml = originalHtml;
        this.originalEvent = originalEvent;
    }
}
