/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import { EditorCommandButton } from './shared/editor-command-button';
import { EditorLocalizationService } from '../localization/editor-localization.service';
import { ProviderService } from '../common/provider.service';
import { EditorToolsService } from './tools.service';
import * as i0 from "@angular/core";
/**
 * A directive that configures a ToolBarButtonComponent as an Editor **Clean Formatting** tool.
 * The directive sets the SVG icon and `click` event handlers for the button.
 * ([see example]({% slug toolbartools_editor %}#toc-built-in-tools))
 *
 * @example
 * ```html
 * <kendo-toolbar-button kendoEditorCleanFormattingButton></kendo-toolbar-button>
 * ```
 * @remarks
 * Applied to: {@link ToolBarButtonComponent}
 */
export declare class EditorCleanFormattingButtonDirective extends EditorCommandButton {
    constructor(button: ToolBarButtonComponent, localization: EditorLocalizationService, providerService: ProviderService, toolsService: EditorToolsService);
    static ɵfac: i0.ɵɵFactoryDeclaration<EditorCleanFormattingButtonDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<EditorCleanFormattingButtonDirective, "kendo-toolbar-button[kendoEditorCleanFormattingButton]", never, {}, {}, never, never, true, never>;
}
