/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import { EditorCommandButton } from '../shared/editor-command-button';
import { EditorLocalizationService } from '../../localization/editor-localization.service';
import { ProviderService } from '../../common/provider.service';
import { EditorToolsService } from '../tools.service';
import * as i0 from "@angular/core";
/**
 * Configures a ToolBarButtonComponent as an Editor **Undo** tool
 * ([see example]({% slug toolbartools_editor %}#toc-built-in-tools)).
 * Sets the SVG icon and `click` event handlers of the button.
 * Updates the `disabled` state of the button based on the cursor position in the editing area.
 *
 * @example
 * ```html
 * <kendo-toolbar-button kendoEditorUndoButton></kendo-toolbar-button>
 * ```
 * @remarks
 * Applied to: {@link ToolBarButtonComponent}
 */
export declare class EditorUndoButtonDirective extends EditorCommandButton {
    constructor(button: ToolBarButtonComponent, localization: EditorLocalizationService, providerService: ProviderService, toolsService: EditorToolsService);
    static ɵfac: i0.ɵɵFactoryDeclaration<EditorUndoButtonDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<EditorUndoButtonDirective, "kendo-toolbar-button[kendoEditorUndoButton]", never, {}, {}, never, never, true, never>;
}
