/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import { EditorCommandButton } from '../shared/editor-command-button';
import { EditorLocalizationService } from '../../localization/editor-localization.service';
import { EditorToolsService } from '../tools.service';
import { ProviderService } from '../../common/provider.service';
import * as i0 from "@angular/core";
/**
 * Configures a ToolBarButtonComponent as an Editor **Print** tool
 * ([see example]({% slug toolbartools_editor %}#toc-built-in-tools)).
 * This directive sets the SVG icon and `click` event handlers for the button.
 *
 * The Editor Print tool works only in the default [`iframe`](slug:api_editor_editorcomponent#iframe) mode.
 *
 * @example
 * ```html
 * <kendo-toolbar-button kendoEditorPrintButton></kendo-toolbar-button>
 * ```
 * @remarks
 * Applied to: {@link ToolBarButtonComponent}
 */
export declare class EditorPrintDirective extends EditorCommandButton {
    constructor(button: ToolBarButtonComponent, localization: EditorLocalizationService, providerService: ProviderService, toolsService: EditorToolsService);
    ngAfterViewInit(): void;
    protected clickHandler(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EditorPrintDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<EditorPrintDirective, "kendo-toolbar-button[kendoEditorPrintButton]", never, {}, {}, never, never, true, never>;
}
